@@ -19,7 +19,6 @@ from openid.extensions import sreg, ax, pape
 from oauth2 import Consumer as OAuthConsumer, Token, Request as OAuthRequest
 
 from django.contrib.auth import authenticate
-from django.contrib.auth.backends import ModelBackend
 from django.utils import simplejson
 from django.utils.importlib import import_module
 
@@ -78,7 +77,7 @@ PIPELINE = setting('SOCIAL_AUTH_PIPELINE', (
            ))
 
 
-class SocialAuthBackend(ModelBackend):
+class SocialAuthBackend(object):
     """A django.contrib.auth backend that authenticates the user based on
     a authentication provider response"""
     name = ''  # provider name, it's stored in database
@@ -186,7 +185,8 @@ class SocialAuthBackend(ModelBackend):
 
     def get_user(self, user_id):
         """
-        Return user with given ID from the User model used by this backend
+        Return user with given ID from the User model used by this backend.
+        This is called by django.contrib.auth.middleware.
         """
         return UserSocialAuth.get_user(user_id)
 
