@@ -89,6 +89,8 @@ class UserSocialAuthMixin(object):
 
     @classmethod
     def get_social_auth(cls, provider, uid):
+        if not isinstance(uid, basestring):
+            uid = str(uid)
         try:
             return cls.objects.get(provider=provider, uid=uid)
         except cls.DoesNotExist:
@@ -100,6 +102,8 @@ class UserSocialAuthMixin(object):
 
     @classmethod
     def create_social_auth(cls, user, uid, provider):
+        if not isinstance(uid, basestring):
+            uid = str(uid)
         return cls.objects.create(user=user, uid=uid, provider=provider)
 
     @classmethod
